********************************************************************************
***			 Variables for analysis of final outcomes						 ***
********************************************************************************

* Number of groups
gen num_groups=.
replace num_groups=12 if treatment==1 | treatment==2 
label variable num_groups "Number of groups in treatment"



*******************
* Period averages *
*******************

* ONE-period mean final_x and final_y by treatment
by treatment period, sort: egen m1all_fin_x = mean(final_x)
by treatment period, sort: egen m1all_fin_y = mean(final_y)
label variable m1all_fin_x "Mean x-coordinate of decisions per treatment per period"
label variable m1all_fin_y "Mean y-coordinate of decisions per treatment per period"


* Distance of outcomes from mean outcome in treatment per period
generate dev1_mean = ((m1all_fin_x - final_x)^2 + (m1all_fin_y - final_y)^2)^0.5
label variable dev1_mean "Distance between group's decision and mean center of groups's decisions in period"


* Standard distance deviation of final outcomes in treatment per period
generate square_dev1_mean = dev1_mean^2
by treatment period type, sort: egen tot_square_dev1_mean = total(square_dev1_mean)
generate std_m1_final = (tot_square_dev1_mean/(num_groups-2))^0.5
label variable std_m1_final "Standard distance deviation of final outcomes in treatment per period"
drop square_dev1_mean tot_square_dev1_mean



**********************
* 20 period averages *
**********************

* TWENTY-period mean final_x and final_y by group
by groupid, sort: egen m20_fin_x = mean(final_x)
by groupid, sort: egen m20_fin_y = mean(final_y)
label variable m20_fin_x "Mean x-coordinate per group of TWENTY-period mean decisions"
label variable m20_fin_y "Mean x-coordinate per group of TWENTY-period mean decisions"


* TWENTY-period mean final_x and final_y by treatment
by treatment, sort: egen m20all_fin_x = mean(final_x)
by treatment, sort: egen m20all_fin_y = mean(final_y)
label variable m20all_fin_x "Mean x-coordinate per treatment of TWENTY-period mean decisions"
label variable m20all_fin_y "Mean y-coordinate per treatnent of TWENTY-period mean decisions"


* TWENTY-period phase mean distance of group decision from mean treatment decision
by groupid, sort: egen dev20_mean = mean(dev1_mean)
label variable dev20_mean "TWENTY-period phase average distance group vs treatment mean decision"


* Mean standard distance deviation of period outcomes per treatment over TWENTY-period phases
by treatment, sort: egen std_m20_final = mean(std_m1_final)
label variable std_m20_final "Standard distance deviation of decisions in treatment per TWENTY-period phases"


* TWENTY-period phase mean distance of current from previous group decision
* Without period 1
by groupid, sort: egen dist_res_sq_20_mean = mean(dist_res_sq) if period>1
label variable dist_res_sq_20_mean "TWENTY-period phase mean distance of current from previous group decision"
gsort +subjectid -period
replace dist_res_sq_20_mean = dist_res_sq_20_mean[_n-1] if dist_res_sq_20_mean >= .
gsort +subjectid +period


* VARIANCE OF OUTCOMES WITHIN GROUPS OVER TIME

* Distance of group's decisions in periods from group's mean center decision 
generate dev_group = ((m20_fin_x - final_x)^2 + (m20_fin_y - final_y)^2)^0.5
label variable dev_group "Distance between group's decision in p. and mean center of groups's decisions in all p.s"


* Standard distance deviation of group's decisions in all periods
generate square_dev_group = dev_group^2
by groupid type, sort: egen tot_square_dev_group = total(square_dev_group)
generate std_group_final = (tot_square_dev_group/(num_groups-2))^0.5
label variable std_group_final "Standard distance deviation of group's decisions in all periods"
drop tot_square_dev_group square_dev_group


* Mean standard distance deviation of group decisions in all periods per treatment
by treatment period type, sort: egen mean_std_group_final = mean(std_group_final)
label variable mean_std_group_final "Mean standard distance deviation of group decisions in all periods per treatment"



**********************
* 10 period averages *
**********************

gen per10=.
replace per10=1 if period<=10
replace per10=2 if period>10

gen help_per10=""
replace help_per10="1-10" if period<=10
replace help_per10="11-20" if period>10

gen marker10=0
replace marker10=1 if period==1
replace marker10=1 if period==11

label define avg_10 1 "Periods 1-10" 2 "Periods 11-20"
label values per10 avg_10


* TEN-period mean final_x and final_y by group
by groupid per10, sort: egen m10_fin_x = mean(final_x)
by groupid per10, sort: egen m10_fin_y = mean(final_y)
label variable m10_fin_x "Mean x-coordinate per group of TEN-period mean decisions"
label variable m10_fin_y "Mean x-coordinate per group of TEN-period mean decisions"


* TEN-period mean final_x and final_y by treatment
by treatment per10, sort: egen m10all_fin_x = mean(final_x)
by treatment per10, sort: egen m10all_fin_y = mean(final_y)
label variable m10all_fin_x "Mean x-coordinate per treatment of TEN-period mean decisions"
label variable m10all_fin_y "Mean y-coordinate per treatnent of TEN-period mean decisions"


* TEN-period phase mean distance of group decision from mean treatment decision
by groupid per10, sort: egen dev10_mean = mean(dev1_mean)
label variable dev10_mean "TEN-period phase average distance group vs treatment mean decision"


* Mean standard distance deviation of period outcomes per treatment over TEN-period phases
by treatment per10, sort: egen std_m10_final = mean(std_m1_final)
label variable std_m10_final "Standard distance deviation of decisions in treatment per TEN-period phases"

* TEN-period phase mean distance of current from previous group decision
* Without period 1
by groupid per10, sort: egen dist_res_sq_10_mean = mean(dist_res_sq) if period>1
label variable dist_res_sq_10_mean "TEN-period phase mean distance of current from previous group decision"
gsort +subjectid -period
replace dist_res_sq_10_mean = dist_res_sq_10_mean[_n-1] if dist_res_sq_10_mean >= .
gsort +subjectid +period

